# admin-lte-2-sass

Sass for [AdminLTE 2](https://github.com/ColorlibHQ/AdminLTE)

| Module | Version |
|--|--|
| AdminLTE | 2.4.10 |
| Bootstrap | 3.4.1 |

## Installation

```shell
$ npm install admin-lte-2-sass
```

```scss
// Implement as you want
@import "~admin-lte-2-sass/assets/scss/AdminLTE";
@import "~admin-lte-2-sass/assets/scss/skins/all-skins";
```

## Development

```shell
$ yarn
$ yarn copy-bootstrap
$ yarn build
```
