---
title: "Flash Jump"
outline: false
---

# Flash Jump

Type a pattern, press a label, jump anywhere visible.

<div class="showcase-demo">
  <img src="./showcase.gif" alt="Flash Jump demo" />
</div>

<!-- Generated by: cargo test --package fresh-editor --test e2e_tests blog_showcase_productivity/flash-jump -- --ignored -->
<!-- Then run: scripts/frames-to-gif.sh docs/blog/productivity/flash-jump -->
