---
title: "Vertical Rulers"
outline: false
---

# Vertical Rulers

Add column rulers to enforce line length limits.

<div class="showcase-demo">
  <img src="./showcase.gif" alt="Vertical Rulers demo" />
</div>

<!-- Generated by: cargo test --package fresh-editor --test e2e_tests blog_showcase_fresh-0.2.3-0.2.9/vertical-rulers -- --ignored -->
<!-- Then run: scripts/frames-to-gif.sh docs/blog/fresh-0.2.3-0.2.9/vertical-rulers -->
