---
title: "Theme Editor Redesign"
outline: false
---

# Theme Editor Redesign

Redesigned theme editor with virtual scrolling, mouse support, and Inspect Theme at Cursor.

<div class="showcase-demo">
  <img src="./showcase.gif" alt="Theme Editor Redesign demo" />
</div>

<!-- Generated by: cargo test --package fresh-editor --test e2e_tests blog_showcase_fresh-0.2.18/theme-editor -- --ignored -->
<!-- Then run: scripts/frames-to-gif.sh docs/blog/fresh-0.2.18/theme-editor -->
