---
title: "Duplicate Line"
outline: false
---

# Duplicate Line

Duplicate the current line with a single command.

<div class="showcase-demo">
  <img src="./showcase.gif" alt="Duplicate Line demo" />
</div>

<!-- Generated by: cargo test --package fresh-editor --test e2e_tests blog_showcase_editing/duplicate-line -- --ignored -->
<!-- Then run: scripts/frames-to-gif.sh docs/blog/editing/duplicate-line -->
