---
title: "Tab Indent Selection"
outline: false
---

# Tab Indent Selection

Tab indents selected lines, Shift+Tab dedents.

<div class="showcase-demo">
  <img src="./showcase.gif" alt="Tab Indent Selection demo" />
</div>

<!-- Generated by: cargo test --package fresh-editor --test e2e_tests blog_showcase_editing/tab-indent -- --ignored -->
<!-- Then run: scripts/frames-to-gif.sh docs/blog/editing/tab-indent -->
