---
title: "Block Selection"
outline: false
---

# Block Selection

Rectangular column editing with Alt+Shift+Arrow.

<div class="showcase-demo">
  <img src="./showcase.gif" alt="Block Selection demo" />
</div>

<!-- Generated by: cargo test --package fresh-editor --test e2e_tests blog_showcase_editing/block-selection -- --ignored -->
<!-- Then run: scripts/frames-to-gif.sh docs/blog/editing/block-selection -->
