---
title: "Auto-Save"
outline: false
---

# Auto-Save

Persistent auto-save writes modified buffers to disk at a configurable interval.

<div class="showcase-demo">
  <img src="./showcase.gif" alt="Auto-Save demo" />
</div>

<!-- Generated by: cargo test --package fresh-editor --test e2e_tests blog_showcase_fresh-0.2.3-0.2.9/auto-save -- --ignored -->
<!-- Then run: scripts/frames-to-gif.sh docs/blog/fresh-0.2.3-0.2.9/auto-save -->
