---
title: "Move Lines"
outline: false
---

# Move Lines

Move lines up and down with Alt+Arrow keys.

<div class="showcase-demo">
  <img src="./showcase.gif" alt="Move Lines demo" />
</div>

<!-- Generated by: cargo test --package fresh-editor --test e2e_tests blog_showcase_editing/line-move -- --ignored -->
<!-- Then run: scripts/frames-to-gif.sh docs/blog/editing/line-move -->
