---
title: "Split View"
outline: false
---

# Split View

Side-by-side editing with independent panes.

<div class="showcase-demo">
  <img src="./showcase.gif" alt="Split View demo" />
</div>

<!-- Generated by: cargo test --package fresh-editor --test e2e_tests blog_showcase_productivity/split-view -- --ignored -->
<!-- Then run: scripts/frames-to-gif.sh docs/blog/productivity/split-view -->
