---
title: "Keybinding Editor"
outline: false
---

# Keybinding Editor

Search, add, edit, and delete key bindings with conflict detection.

<div class="showcase-demo">
  <img src="./showcase.gif" alt="Keybinding Editor demo" />
</div>

<!-- Generated by: cargo test --package fresh-editor --test e2e_tests blog_showcase_productivity/keybinding-editor -- --ignored -->
<!-- Then run: scripts/frames-to-gif.sh docs/blog/productivity/keybinding-editor -->
