---
title: "30 New Syntax Grammars"
outline: false
---

# 30 New Syntax Grammars

Dockerfile, Nix, Svelte, Vue, Kotlin, Swift, and 24 more languages with syntax highlighting.

<div class="showcase-demo">
  <img src="./showcase.gif" alt="30 New Syntax Grammars demo" />
</div>

<!-- Generated by: cargo test --package fresh-editor --test e2e_tests blog_showcase_fresh-0.2.18/syntax-grammars -- --ignored -->
<!-- Then run: scripts/frames-to-gif.sh docs/blog/fresh-0.2.18/syntax-grammars -->
