---
title: "Git Log"
outline: false
---

# Git Log

Magit-style git log with live-preview: a buffer-group tab pairs the aligned commit list with the selected commit's detail, updated as you navigate.

<div class="showcase-demo">
  <img src="./showcase.gif" alt="Git Log demo" />
</div>

Learn more: [Git feature page](/features/git).

<!-- Generated by: cargo test --package fresh-editor --test e2e_tests blog_showcase_fresh-0.3.0/git-log -- --ignored -->
<!-- Then run: scripts/frames-to-gif.sh docs/blog/fresh-0.3.0/git-log -->
