---
title: "Smart Editing"
outline: false
---

# Smart Editing

Smart Home, smart backspace dedent, and improved auto-indent.

<div class="showcase-demo">
  <img src="./showcase.gif" alt="Smart Editing demo" />
</div>

<!-- Generated by: cargo test --package fresh-editor --test e2e_tests blog_showcase_fresh-0.2.9/smart-editing -- --ignored -->
<!-- Then run: scripts/frames-to-gif.sh docs/blog/fresh-0.2.9/smart-editing -->
