---
title: "Accurate Line Numbers for Large Files"
outline: false
---

# Accurate Line Numbers for Large Files

On-demand parallel line scan gives exact line numbers and precise Go to Line.

<div class="showcase-demo">
  <img src="./showcase.gif" alt="Accurate Line Numbers for Large Files demo" />
</div>

<!-- Generated by: cargo test --package fresh-editor --test e2e_tests blog_showcase_fresh-0.2.3-0.2.9/large-file-scanning -- --ignored -->
<!-- Then run: scripts/frames-to-gif.sh docs/blog/fresh-0.2.3-0.2.9/large-file-scanning -->
