---
title: "Case Conversion"
outline: false
---

# Case Conversion

Convert selected text to uppercase (Alt+U) or lowercase (Alt+L).

<div class="showcase-demo">
  <img src="./showcase.gif" alt="Case Conversion demo" />
</div>

<!-- Generated by: cargo test --package fresh-editor --test e2e_tests blog_showcase_editing/case-conversion -- --ignored -->
<!-- Then run: scripts/frames-to-gif.sh docs/blog/editing/case-conversion -->
