---
title: "Triple-Click Selection"
outline: false
---

# Triple-Click Selection

Triple-click to select an entire line.

<div class="showcase-demo">
  <img src="./showcase.gif" alt="Triple-Click Selection demo" />
</div>

<!-- Generated by: cargo test --package fresh-editor --test e2e_tests blog_showcase_editing/triple-click -- --ignored -->
<!-- Then run: scripts/frames-to-gif.sh docs/blog/editing/triple-click -->
