---
title: "Dashboard"
outline: false
---

# Dashboard

Opt-in TUI dashboard replaces the default [No Name] buffer with weather, git status, GitHub PRs, and disk usage.

<div class="showcase-demo">
  <img src="./showcase.gif" alt="Dashboard demo" />
</div>

Learn more: [Dashboard feature page](/features/dashboard).

<!-- Generated by: cargo test --package fresh-editor --test e2e_tests blog_showcase_fresh-0.3.0/dashboard -- --ignored -->
<!-- Then run: scripts/frames-to-gif.sh docs/blog/fresh-0.3.0/dashboard -->
