---
title: "Settings UI"
outline: false
---

# Settings UI

Graphical editor for all configuration options.

<div class="showcase-demo">
  <img src="./showcase.gif" alt="Settings UI demo" />
</div>

<!-- Generated by: cargo test --package fresh-editor --test e2e_tests blog_showcase_productivity/settings -- --ignored -->
<!-- Then run: scripts/frames-to-gif.sh docs/blog/productivity/settings -->
