---
title: "Integrated Terminal"
outline: false
---

# Integrated Terminal

Split terminal with scrollback and session persistence.

<div class="showcase-demo">
  <img src="./showcase.gif" alt="Integrated Terminal demo" />
</div>

<!-- Generated by: cargo test --package fresh-editor --test e2e_tests blog_showcase_productivity/terminal -- --ignored -->
<!-- Then run: scripts/frames-to-gif.sh docs/blog/productivity/terminal -->
