---
title: "Surround Selection"
outline: false
---

# Surround Selection

Select text and type a delimiter to wrap it.

<div class="showcase-demo">
  <img src="./showcase.gif" alt="Surround Selection demo" />
</div>

<!-- Generated by: cargo test --package fresh-editor --test e2e_tests blog_showcase_fresh-0.2.18/surround-selection -- --ignored -->
<!-- Then run: scripts/frames-to-gif.sh docs/blog/fresh-0.2.18/surround-selection -->
