---
title: "Markdown Compose Mode"
outline: false
---

# Markdown Compose Mode

Distraction-free writing with concealed markup and table rendering.

<div class="showcase-demo">
  <img src="./showcase.gif" alt="Markdown Compose Mode demo" />
</div>

<!-- Generated by: cargo test --package fresh-editor --test e2e_tests blog_showcase_fresh-0.2.3-0.2.9/compose-mode -- --ignored -->
<!-- Then run: scripts/frames-to-gif.sh docs/blog/fresh-0.2.3-0.2.9/compose-mode -->
