---
title: "Search & Replace"
outline: false
---

# Search & Replace

Find and replace with incremental highlighting.

<div class="showcase-demo">
  <img src="./showcase.gif" alt="Search & Replace demo" />
</div>

<!-- Generated by: cargo test --package fresh-editor --test e2e_tests blog_showcase_editing/search-replace -- --ignored -->
<!-- Then run: scripts/frames-to-gif.sh docs/blog/editing/search-replace -->
