---
title: "Command Palette"
outline: false
---

# Command Palette

Unified access to files, commands, buffers, and line navigation.

<div class="showcase-demo">
  <img src="./showcase.gif" alt="Command Palette demo" />
</div>

<!-- Generated by: cargo test --package fresh-editor --test e2e_tests blog_showcase_productivity/command-palette -- --ignored -->
<!-- Then run: scripts/frames-to-gif.sh docs/blog/productivity/command-palette -->
