---
title: "File Explorer"
outline: false
---

# File Explorer

Sidebar tree view with fuzzy search and git indicators.

<div class="showcase-demo">
  <img src="./showcase.gif" alt="File Explorer demo" />
</div>

<!-- Generated by: cargo test --package fresh-editor --test e2e_tests blog_showcase_productivity/file-explorer -- --ignored -->
<!-- Then run: scripts/frames-to-gif.sh docs/blog/productivity/file-explorer -->
