# Comprehensive UI A

**Category**: Visual Regression

*File explorer open, line wrap on, multicursors, diagnostics, scrolled*

---

## Step 1: state_a

![state_a](../screenshots/Comprehensive_UI_A_01_state_a.svg)

*File explorer open + syntax highlighting + diagnostics + multicursors + scrolled*

