# Fenced code demo

Some prose before the code.

```rust
fn answer() -> u32 {
    let greeting = "hello";
    42
}
```

Prose between blocks.

```nosuchlanguage
fn answer() -> u32 { 42 }
```

Trailing prose.
