# Comprehensive UI B

**Category**: Visual Regression

*Command palette open, split view, line wrap off, horizontal scroll*

---

## Step 1: state_b

![state_b](../screenshots/Comprehensive_UI_B_01_state_b.svg)

*Split view + command palette open + line wrap off + horizontal scroll*

